@@ -265,7 +265,7 @@ def make_socket_local(rpath):
 def gzip_open_local_read(rpath):
 	"""Return open GzipFile.  See security note directly above"""
 	assert rpath.conn is Globals.local_connection
-	return gzip.GzipFile(rpath.path, "rb")
+	return GzipFile(rpath.path, "rb")
 
 def open_local_read(rpath):
 	"""Return open file (provided for security reasons)"""
@@ -357,8 +357,10 @@ class RORPath:
 			elif key == 'resourcefork' and not Globals.resource_forks_write:
 				pass
 			elif key == 'sha1': pass # one or other may not have set
+			elif key == 'mirrorname' or key == 'incname': pass
 			elif (not other.data.has_key(key) or
-				  self.data[key] != other.data[key]): return 0
+				  self.data[key] != other.data[key]):
+				return 0
 
 		if self.lstat() and not self.issym() and Globals.change_ownership:
 			# Now compare ownership.  Symlinks don't have ownership
@@ -654,6 +656,42 @@ class RORPath:
 		"""Record resource fork in dictionary.  Does not write"""
 		self.data['resourcefork'] = rfork
 
+	def has_alt_mirror_name(self):
+		"""True if rorp has an alternate mirror name specified"""
+		return self.data.has_key('mirrorname')
+
+	def get_alt_mirror_name(self):
+		"""Return alternate mirror name (for long filenames)"""
+		return self.data['mirrorname']
+
+	def set_alt_mirror_name(self, filename):
+		"""Set alternate mirror name to filename
+
+		Instead of writing to the traditional mirror file, store
+		mirror information in filename in the long filename
+		directory.
+
+		"""
+		self.data['mirrorname'] = filename
+
+	def has_alt_inc_name(self):
+		"""True if rorp has an alternate increment base specified"""
+		return self.data.has_key('incname')
+
+	def get_alt_inc_name(self):
+		"""Return alternate increment base (used for long name support)"""
+		return self.data['incname']
+
+	def set_alt_inc_name(self, name):
+		"""Set alternate increment name to name
+
+		If set, increments will be in the long name directory with
+		name as their base.  If the alt mirror name is set, this
+		should be set to the same.
+
+		"""
+		self.data['incname'] = name
+
 	def has_sha1(self):
 		"""True iff self has its sha1 digest set"""
 		return self.data.has_key('sha1')
@@ -982,13 +1020,13 @@ class RPath(RORPath):
 
 		"""
 		if self.conn is Globals.local_connection:
-			if compress: return gzip.GzipFile(self.path, mode)
+			if compress: return GzipFile(self.path, mode)
 			else: return open(self.path, mode)
 
 		if compress:
 			if mode == "r" or mode == "rb":
 				return self.conn.rpath.gzip_open_local_read(self)
-			else: return self.conn.gzip.GzipFile(self.path, mode)
+			else: return self.conn.rpath.GzipFile(self.path, mode)
 		else:
 			if mode == "r" or mode == "rb":
 				return self.conn.rpath.open_local_read(self)
@@ -1217,6 +1255,16 @@ class RPathFileHook:
 		return result
 
 
+class GzipFile(gzip.GzipFile):
+	"""Like gzip.GzipFile, except remove destructor
+
+	The default GzipFile's destructor prints out some messy error
+	messages.  Use this class instead to clean those up.
+
+	"""
+	def __del__(self): pass
+
+
 def setdata_local(rpath):
 	"""Set eas/acls, uid/gid, resource fork in data dictionary
 
@@ -1239,7 +1287,7 @@ def carbonfile_get(rpath):
 	from Carbon.File import FSSpec
 	import MacOS
 	try:
-		fsobj = FSSpec(self.path)
+		fsobj = FSSpec(rpath.path)
 		finderinfo = fsobj.FSpGetFInfo()
 		cfile = {'creator': finderinfo.Creator,
 				 'type': finderinfo.Type,
@@ -1248,7 +1296,7 @@ def carbonfile_get(rpath):
 		return cfile
 	except MacOS.Error:
 		log.Log("Cannot read carbonfile information from %s" %
-				(self.path,), 2)
+				(rpath.path,), 2)
 		return None
 
 
